@@ -87,7 +87,7 @@ class USSD_Controller:
 		fconfig.writelines(["#Show banner\n", "show_box="+str(self.config[11]), "\n"])
 		fconfig.writelines(["#USSD reply language\n", "language="+str(self.config[10]), "\n"])
 		fconfig.writelines(["#Additional ussdquery.py arguments\n", "args="+self.config[13], "\n"])
-		fconfig.writelines(["#Regexp matching group\n", "reggroup="+self.config[14], "\n"])
+		fconfig.writelines(["#Regexp matching group\n", "reggroup="+str(self.config[14]), "\n"])
 		fconfig.close()
 
 		fcntl.flock(lockf,fcntl.LOCK_UN)
